package cmd

import (
	"fmt"
	"time"
)

var (
	Version            = "v0.0.0"
	Commit             = "00000000"
	BuildTimeFormatted = "1970-01-01T00:00:00+00:00"
	BuildTime          time.Time
)

const (
	// NOTE: this is a hack to support outdated `date` commands
	// that produce an invalid RFC3339 formatted string via `-u`.
	// Known affected distributions are:
	// - Amazon Linux 2 (based on CentOS 7)
	// - CentOS 7
	// - Oracle Linux 7 (based on CentOS 7)
	// - Scientific Linux 7 (based on CentOS 7)
	// See https://gitlab.com/gitlab-org/cluster-integration/gitlab-agent/-/issues/572
	// Please remove this workaround at latest with GitLab 18.0,
	// see https://gitlab.com/gitlab-org/cluster-integration/gitlab-agent/-/issues/573
	rfc3339ish = "2006-01-02T15:04:05Z0700"
)

func init() {
	BuildTime = parseBuildTime(BuildTimeFormatted)
}

func parseBuildTime(formatted string) time.Time {
	bt, err := time.Parse(time.RFC3339, formatted)
	if err != nil {
		// HACK: support outdated `date` commands - see comment on RFC3339ish constant.
		bt, err = time.Parse(rfc3339ish, formatted)
		if err != nil {
			panic(fmt.Errorf("failed to parse %q into RFC3339 compliant time object, because: %w. Fix the build process", formatted, err))
		}
	}
	return bt
}
